@@ -5,19 +5,25 @@ use warnings;
 # ABSTRACT: Module collection to parse Matroska files.
 package Parse::Matroska;
 {
-  $Parse::Matroska::VERSION = '0.001';
+  $Parse::Matroska::VERSION = '0.001001';
 }
+
+
+use Parse::Matroska::Reader;
+
+1;
+
+__END__
+
+=pod
+
 =head1 NAME
 
-Parse::Matroska
+Parse::Matroska - Module collection to parse Matroska files.
 
 =head1 VERSION
 
-version 0.001
-
-=head1 ABSTRACT
-
-Module collection to parse Matroska files.
+version 0.001001
 
 =head1 DESCRIPTION
 
@@ -25,13 +31,24 @@ C<use>s L<Parse::Matroska::Reader>. See the documentation
 of the modules mentioned in L</"SEE ALSO"> for more information
 in how to use this module.
 
+It's intended for this module to contain high-level interfaces
+to the other modules in the distribution.
+
 =head1 SEE ALSO
 
 L<Parse::Matroska::Reader>, L<Parse::Matroska::Element>,
 L<Parse::Matroska::Definitions>.
 
+=head1 AUTHOR
+
+Kovensky <diogomfranco@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Diogo Franco.
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
 =cut
-
-use Parse::Matroska::Reader;
-
-1;
