@@ -2,19 +2,12 @@ use 5.008;
 use strict;
 use warnings;
 
+# ABSTRACT: a low-level reader for EBML files
 package Parse::Matroska::Reader;
 {
-  $Parse::Matroska::Reader::VERSION = '0.001';
+  $Parse::Matroska::Reader::VERSION = '0.001001';
 }
-=head1 NAME
 
-Parse::Matroska::Reader
-
-=head1 VERSION
-
-version 0.001
-
-=cut
 use Parse::Matroska::Definitions qw{elem_by_hexid};
 use Parse::Matroska::Element;
 
@@ -25,45 +18,6 @@ use IO::File;
 use List::Util qw{first};
 use Encode;
 
-=head1 SYNOPSIS
-
-    use Parse::Matroska::Reader;
-    my $reader = Parse::Matroska::Reader->new($path);
-    $reader->close;
-    $reader->open(\$string_with_matroska_data);
-
-    my $elem = $reader->read_element;
-    print "Element ID: $elem->{elid}\n";
-    print "Element name: $elem->{name}\n";
-    if ($elem->{type} ne 'sub') {
-        print "Element value: $elem->get_value\n";
-    } else {
-        while (my $child = $elem->next_child) {
-            print "Child element: $child->{name}\n";
-        }
-    }
-    $reader->close;
-
-=head1 DESCRIPTION
-
-Reads EBML data, which is used in Matroska files.
-This is a low-level reader which is meant to be used as a backend
-for higher level readers. TODO: write the high level readers :)
-
-=head1 NOTE
-
-The API of this module is not yet considered stable.
-
-=head1 METHODS
-
-=over
-
-=item new
-
-Creates a new reader.
-Calls L</open(arg)> with its arguments if provided.
-
-=cut
 sub new {
     my $class = shift;
     my $self = {};
@@ -73,36 +27,12 @@ sub new {
     return $self;
 }
 
-=item open(arg)
-
-Creates the internal filehandle. The argument can be:
-
-=over
-
-=item * An open filehandle or L<IO::Handle> object.
-The filehandle is not C<dup()>ed, so calling L</close> in
-this object will close the given filehandle as well.
-
-=item * A scalar containing a path to a file.
-
-=item * On perl v5.14 or newer, a scalarref pointing to
-EBML data. For similar functionality in older perls,
-give an L<IO::String> object.
-
-=back
-
-=cut
 sub open {
     my ($self, $arg) = @_;
     $self->{fh} = openhandle($arg) || IO::File->new($arg, "<:raw")
         or croak "Can't open $arg: $!";
 }
 
-=item close
-
-Closes the internal filehandle.
-
-=cut
 sub close {
     my ($self) = @_;
     $self->{fh}->close;
@@ -117,11 +47,6 @@ sub _getc {
     return $c;
 }
 
-=item readlen(length)
-
-Reads C<length> bytes from the internal filehandle.
-
-=cut
 sub readlen {
     my ($self, $len) = @_;
     my $data;
@@ -155,12 +80,6 @@ sub _ldexp {
 # of even harder to read python functions.
 # TODO: make them readable
 
-=item read_id
-
-Reads an EBML ID atom in hexadecimal string format, suitable
-for passing to L<Parse::Matroska::Definitions/elem_by_hexid>.
-
-=cut
 sub read_id {
     my ($self) = @_;
     my $t = $self->_getc;
@@ -179,23 +98,6 @@ sub read_id {
     return unpack "H*", ($t . $self->readlen($i));
 }
 
-=item read_size
-
-Reads an EBML Data Size atom, which immediately follows
-an EBML ID atom.
-
-This returns an array consisting of:
-
-=over
-
-=item 0 The length of the Data Size atom.
-
-=item 1 The value encoded in the Data Size atom,
-which is the length of all the data following it.
-
-=back
-
-=cut
 sub read_size {
     my ($self) = @_;
     my $t = $self->_getc;
@@ -213,13 +115,6 @@ sub read_size {
     return ($i+1, _bin2int $t . $self->readlen($i));
 }
 
-=item read_str(length)
-
-Reads a string of length C<length> bytes from the internal filehandle.
-The string is already L<Encode/decode>d from C<UTF-8>, which is the
-standard Matroska string encoding.
-
-=cut
 {
     my $utf8 = find_encoding("UTF-8");
     sub read_str {
@@ -228,29 +123,11 @@ standard Matroska string encoding.
     }
 }
 
-=item read_uint(length)
-
-Reads an unsigned integer of length C<length> bytes
-from the internal filehandle.
-
-Returns a L<Math::BigInt> object if C<length> is greater
-than 4.
-
-=cut
 sub read_uint {
     my ($self, $length) = @_;
     return _bin2int $self->readlen($length);
 }
 
-=item read_sint(length)
-
-Reads a signed integer of length C<length> bytes
-from the internal filehandle.
-
-Returns a L<Math::BigInt> object if C<length> is greater
-than 4.
-
-=cut
 sub read_sint {
     my ($self, $length) = @_;
     my $i = $self->read_uint($length);
@@ -265,14 +142,6 @@ sub read_sint {
     return $i;
 }
 
-=item read_float(length)
-
-Reads an IEEE floating point number of length C<length>
-bytes from the internal filehandle.
-
-Only lengths '4' and '8' are supported (C 'float' and 'double').
-
-=cut
 sub read_float {
     my ($self, $length) = @_;
     my $i = $self->read_uint($length);
@@ -293,26 +162,11 @@ sub read_float {
     return $f;
 }
 
-=item read_ebml_id(length)
-
-Reads an EBML ID when it's encoded as the data inside
-another EBML element, that is, when the enclosing element's
-C<type> is "ebml_id".
-
-This returns a hashref with the EBML element description as
-defined in L<Parse::Matroska::Definitions>.
-
-=cut
 sub read_ebml_id {
     my ($self, $length) = @_;
     return elem_by_hexid(unpack("H*", $self->readlen($length)));
 }
 
-=item skip(length)
-
-Skips C<length> bytes in the internal filehandle.
-
-=cut
 sub skip {
     my ($self, $len) = @_;
     return if $self->{fh}->can('seek') && $self->{fh}->seek($len, 1);
@@ -320,30 +174,12 @@ sub skip {
     return;
 }
 
-=item getpos
-
-Wrapper for L<IO::Seekable/$io-E<gt>getpos> in the internal filehandle.
-
-Returns undef if the internal filehandle can't C<getpos>.
-
-=cut
 sub getpos {
     my ($self) = @_;
     return undef unless $self->{fh}->can('getpos');
     return $self->{fh}->getpos;
 }
 
-=item setpos(pos)
-
-Wrapper for L<IO::Seekable/$io-E<gt>setpos> in the internal filehandle.
-
-Returns undef if the internal filehandle can't C<setpos>.
-
-Croaks if C<setpos> does not seek to the requested position,
-that is, if calling C<getpos> does not yield the same object
-as the C<pos> argument.
-
-=cut
 sub setpos {
     my ($self, $pos) = @_;
     return undef unless $pos && $self->{fh}->can('setpos');
@@ -354,26 +190,6 @@ sub setpos {
     return $ret;
 }
 
-=item read_element(read_bin)
-
-Reads a full EBML element from the internal filehandle.
-
-Returns a L<Parse::Matroska::Element> initialized with the
-read data. If C<read_bin> is not present or is false, will
-delay-load the contents of 'binary' type elements, that is,
-they will only be loaded when calling C<get_value> on the
-returned L<Parse::Matroska::Element> object.
-
-Does not read the children of the element if its type is
-'sub'. Look into the L<Parse::Matroska::Element> interface
-for details in how to read children elements.
-
-Pass a true C<read_bin> if the stream being read is not
-seekable (C<getpos> is undef) and the contents of 'binary'
-elements is desired, otherwise seeking errors or
-internal filehandle corruption might occur.
-
-=cut
 sub read_element {
     my ($self, $read_bin) = @_;
     return undef if $self->{fh}->eof;
@@ -430,29 +246,211 @@ sub read_element {
 
 1;
 
+__END__
+
+=pod
+
+=head1 NAME
+
+Parse::Matroska::Reader - a low-level reader for EBML files
+
+=head1 VERSION
+
+version 0.001001
+
+=head1 SYNOPSIS
+
+    use Parse::Matroska::Reader;
+    my $reader = Parse::Matroska::Reader->new($path);
+    $reader->close;
+    $reader->open(\$string_with_matroska_data);
+
+    my $elem = $reader->read_element;
+    print "Element ID: $elem->{elid}\n";
+    print "Element name: $elem->{name}\n";
+    if ($elem->{type} ne 'sub') {
+        print "Element value: $elem->get_value\n";
+    } else {
+        while (my $child = $elem->next_child) {
+            print "Child element: $child->{name}\n";
+        }
+    }
+    $reader->close;
+
+=head1 DESCRIPTION
+
+Reads EBML data, which is used in Matroska files.
+This is a low-level reader which is meant to be used as a backend
+for higher level readers. TODO: write the high level readers :)
+
+=head1 METHODS
+
+=head2 new
+
+Creates a new reader.
+Calls L</open($arg)> with its arguments if provided.
+
+=head2 open($arg)
+
+Creates the internal filehandle. The argument can be:
+
+=over 4
+
+=item *
+
+An open filehandle or L<IO::Handle> object.
+
+The filehandle is not C<dup()>ed, so calling L</close> in this
+object will close the given filehandle as well.
+
+=item *
+
+A scalar containing a path to a file.
+
+=item *
+
+On perl v5.14 or newer, a scalarref pointing to EBML data.
+
+For similar functionality in older perls, give an L<IO::String> object
+or the handle to an already C<open>ed scalarref.
+
 =back
 
+=head2 close
+
+Closes the internal filehandle.
+
+=head2 readlen($length)
+
+Reads C<$length> bytes from the internal filehandle.
+
+=head2 read_id
+
+Reads an EBML ID atom in hexadecimal string format, suitable
+for passing to L<Parse::Matroska::Definitions/elem_by_hexid($id)>.
+
+=head2 read_size
+
+Reads an EBML Data Size atom, which immediately follows
+an EBML ID atom.
+
+This returns an array consisting of:
+
+=over 4
+
+=item 1
+
+The length of the Data Size atom.
+
+=item 2
+
+The value encoded in the Data Size atom, which is the length of all the data following it.
+
+=back
+
+=head2 read_str($length)
+
+Reads a string of length C<$length> bytes from the internal filehandle.
+The string is already L<Encode/decode>d from C<UTF-8>, which is the
+standard Matroska string encoding.
+
+=head2 read_uint($length)
+
+Reads an unsigned integer of length C<$length> bytes
+from the internal filehandle.
+
+Returns a L<Math::BigInt> object if C<$length> is greater
+than 4.
+
+=head2 read_sint($length)
+
+Reads a signed integer of length C<$length> bytes
+from the internal filehandle.
+
+Returns a L<Math::BigInt> object if C<$length> is greater
+than 4.
+
+=head2 read_float($length)
+
+Reads an IEEE floating point number of length C<$length>
+bytes from the internal filehandle.
+
+Only lengths C<4> and C<8> are supported (C C<float> and C<double>).
+
+=head2 read_ebml_id($length)
+
+Reads an EBML ID when it's encoded as the data inside another
+EBML element, that is, when the enclosing element's C<type> is
+C<ebml_id>.
+
+This returns a hashref with the EBML element description as
+defined in L<Parse::Matroska::Definitions>.
+
+=head2 skip($length)
+
+Skips C<$length> bytes in the internal filehandle.
+
+=head2 getpos
+
+Wrapper for L<IO::Seekable/$io-E<gt>getpos> in the internal filehandle.
+
+Returns undef if the internal filehandle can't C<getpos>.
+
+=head2 setpos($pos)
+
+Wrapper for L<IO::Seekable/$io-E<gt>setpos> in the internal filehandle.
+
+Returns C<undef> if the internal filehandle can't C<setpos>.
+
+Croaks if C<setpos> does not seek to the requested position,
+that is, if calling C<getpos> does not yield the same object
+as the C<$pos> argument.
+
+=head2 read_element($read_bin)
+
+Reads a full EBML element from the internal filehandle.
+
+Returns a L<Parse::Matroska::Element> object initialized with
+the read data. If C<read_bin> is not present or is false, will
+delay-load the contents of C<binary> type elements, that is,
+they will only be loaded when calling C<get_value> on the
+returned L<Parse::Matroska::Element> object.
+
+Does not read the children of the element if its type is
+C<sub>. Look into the L<Parse::Matroska::Element> interface
+for details in how to read children elements.
+
+Pass a true C<$read_bin> if the stream being read is not
+seekable (C<getpos> is undef) and the contents of C<binary>
+elements is desired, otherwise seeking errors or internal
+filehandle corruption might occur.
+
+=head1 NOTE
+
+The API of this module is not yet considered stable.
+
 =head1 CAVEATS
 
 Children elements have to be processed as soon as an element
 with children is found, or their children ignored with
 L<Parse::Matroska::Element/skip>. Not doing so doesn't cause
-errors but results in an invalid structure, with constant '0'
+errors but results in an invalid structure, with constant C<0>
 depth.
 
 To work correctly in unseekable streams, either the contents
-of 'binary'-type elements has to be ignored or the C<read_bin>
+of C<binary>-type elements has to be ignored or the C<read_bin>
 flag to C<read_element> has to be true.
 
 =head1 AUTHOR
 
-Diogo Franco <diogomfranco@gmail.com>, aka Kovensky.
-Initially based on a python script by Uoti Urpala.
+Kovensky <diogomfranco@gmail.com>
 
-=head1 SEE ALSO
+=head1 COPYRIGHT AND LICENSE
 
-L<Parse::Matroska::Definitions>, L<Parse::Matroska::Element>.
+This software is Copyright (c) 2012 by Diogo Franco.
 
-=head1 LICENSE
+This is free software, licensed under:
 
-The FreeBSD license, equivalent to the ISC license.
+  The (two-clause) FreeBSD License
+
+=cut
